<?php

namespace App\Models;

use EloquentFilter\Filterable;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\HasOne;
use Illuminate\Foundation\Auth\User as Authenticate;
use Illuminate\Notifications\Notifiable;
use Laravel\Fortify\TwoFactorAuthenticatable;
use Laravel\Sanctum\HasApiTokens;

class User extends Authenticate implements MustVerifyEmail
{
    use HasApiTokens, HasFactory, Notifiable, Filterable, TwoFactorAuthenticatable;

    /**
     * @var array<int, string>
     */
    protected $fillable = [
        'uuid',
        'first_name',
        'last_name',
        'username',
        'email',
        'phone',
        'image',
        'email_verified_at',
        'kyc_status',
        'status',
        'password',
        'referral_by',
        'position_id',
        'position',
        'remember_token',
        'google_id',
        'facebook_id',
        'meta',
    ];

    /**
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
        'meta',
    ];

    /**
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'password' => 'hashed',
        'meta' => 'json'
    ];


    public function getFullNameAttribute(): string
    {
        return $this->first_name . ' ' . $this->last_name;
    }

    /**
     * @return HasOne
     */
    public function wallet(): HasOne
    {
        return $this->hasOne(Wallet::class, 'user_id');
    }


    public function referredBy(): BelongsTo
    {
        return $this->belongsTo(User::class, 'referral_by');
    }

    public function referredUsers(): HasMany
    {
        return $this->hasMany(User::class, 'referral_by');
    }

    public function positionedAbove(): BelongsTo
    {
        return $this->belongsTo(User::class, 'position_id');
    }


    public function recursiveReferrals(): HasMany
    {
        return $this->referredUsers()->with('recursiveReferrals');
    }


    public function matrixInvestemnt(): HasOne
    {
        return $this->hasOne(MatrixInvestment::class, 'user_id');
    }


}
